reply

package
v0.9.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 8, 2023 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CreateReplyRequestBodyFromDiscriminatorValue

CreateReplyRequestBodyFromDiscriminatorValue creates a new instance of the appropriate class based on discriminator value

Types

type ReplyRequestBody

type ReplyRequestBody struct {
	// contains filtered or unexported fields
}

ReplyRequestBody provides operations to call the reply method.

func NewReplyRequestBody

func NewReplyRequestBody() *ReplyRequestBody

NewReplyRequestBody instantiates a new replyRequestBody and sets the default values.

func (*ReplyRequestBody) GetAdditionalData

func (m *ReplyRequestBody) GetAdditionalData() map[string]interface{}

GetAdditionalData gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

func (*ReplyRequestBody) GetFieldDeserializers

GetFieldDeserializers the deserialization information for the current model

func (*ReplyRequestBody) GetPost

GetPost gets the post property value. The Post property

func (*ReplyRequestBody) Serialize

Serialize serializes information the current object

func (*ReplyRequestBody) SetAdditionalData

func (m *ReplyRequestBody) SetAdditionalData(value map[string]interface{})

SetAdditionalData sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

func (*ReplyRequestBody) SetPost

SetPost sets the post property value. The Post property

type ReplyRequestBuilder

type ReplyRequestBuilder struct {
	// contains filtered or unexported fields
}

ReplyRequestBuilder provides operations to call the reply method.

func NewReplyRequestBuilder

NewReplyRequestBuilder instantiates a new ReplyRequestBuilder and sets the default values.

func NewReplyRequestBuilderInternal

func NewReplyRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *ReplyRequestBuilder

NewReplyRequestBuilderInternal instantiates a new ReplyRequestBuilder and sets the default values.

func (*ReplyRequestBuilder) CreatePostRequestInformation

CreatePostRequestInformation invoke action reply

func (*ReplyRequestBuilder) Post

Post invoke action reply

type ReplyRequestBuilderPostOptions

type ReplyRequestBuilderPostOptions struct {
	//
	Body ReplyRequestBodyable
	// Request headers
	Headers map[string]string
	// Request options
	Options []i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestOption
	// Response handler to use in place of the default response handling provided by the core service
	ResponseHandler i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.ResponseHandler
}

ReplyRequestBuilderPostOptions options for Post

Jump to