Documentation
¶
Index ¶
- type AttachmentsRequestBuilder
- func (m *AttachmentsRequestBuilder) Count() ...
- func (m *AttachmentsRequestBuilder) CreateGetRequestInformation(options *AttachmentsRequestBuilderGetOptions) (...)
- func (m *AttachmentsRequestBuilder) CreatePostRequestInformation(options *AttachmentsRequestBuilderPostOptions) (...)
- func (m *AttachmentsRequestBuilder) CreateUploadSession() ...
- func (m *AttachmentsRequestBuilder) Get(options *AttachmentsRequestBuilderGetOptions) (...)
- func (m *AttachmentsRequestBuilder) Post(options *AttachmentsRequestBuilderPostOptions) (...)
- type AttachmentsRequestBuilderGetOptions
- type AttachmentsRequestBuilderGetQueryParameters
- type AttachmentsRequestBuilderPostOptions
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AttachmentsRequestBuilder ¶
type AttachmentsRequestBuilder struct {
// contains filtered or unexported fields
}
AttachmentsRequestBuilder provides operations to manage the attachments property of the microsoft.graph.event entity.
func NewAttachmentsRequestBuilder ¶
func NewAttachmentsRequestBuilder(rawUrl string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *AttachmentsRequestBuilder
NewAttachmentsRequestBuilder instantiates a new AttachmentsRequestBuilder and sets the default values.
func NewAttachmentsRequestBuilderInternal ¶
func NewAttachmentsRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *AttachmentsRequestBuilder
NewAttachmentsRequestBuilderInternal instantiates a new AttachmentsRequestBuilder and sets the default values.
func (*AttachmentsRequestBuilder) Count ¶
func (m *AttachmentsRequestBuilder) Count() *i75b2f73f2478eed80735721b3b0fe010ed94c24de802e532ceb8d9265ab764e1.CountRequestBuilder
Count the count property
func (*AttachmentsRequestBuilder) CreateGetRequestInformation ¶
func (m *AttachmentsRequestBuilder) CreateGetRequestInformation(options *AttachmentsRequestBuilderGetOptions) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
CreateGetRequestInformation the collection of FileAttachment, ItemAttachment, and referenceAttachment attachments for the event. Navigation property. Read-only. Nullable.
func (*AttachmentsRequestBuilder) CreatePostRequestInformation ¶
func (m *AttachmentsRequestBuilder) CreatePostRequestInformation(options *AttachmentsRequestBuilderPostOptions) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
CreatePostRequestInformation create new navigation property to attachments for me
func (*AttachmentsRequestBuilder) CreateUploadSession ¶
func (m *AttachmentsRequestBuilder) CreateUploadSession() *i5a8827d173d955230ea6bc48bacf30d7c3dd3bb936838eda7584b94d5f4993ec.CreateUploadSessionRequestBuilder
CreateUploadSession the createUploadSession property
func (*AttachmentsRequestBuilder) Get ¶
func (m *AttachmentsRequestBuilder) Get(options *AttachmentsRequestBuilderGetOptions) (iadcd81124412c61e647227ecfc4449d8bba17de0380ddda76f641a29edf2b242.AttachmentCollectionResponseable, error)
Get the collection of FileAttachment, ItemAttachment, and referenceAttachment attachments for the event. Navigation property. Read-only. Nullable.
func (*AttachmentsRequestBuilder) Post ¶
func (m *AttachmentsRequestBuilder) Post(options *AttachmentsRequestBuilderPostOptions) (iadcd81124412c61e647227ecfc4449d8bba17de0380ddda76f641a29edf2b242.Attachmentable, error)
Post create new navigation property to attachments for me
type AttachmentsRequestBuilderGetOptions ¶
type AttachmentsRequestBuilderGetOptions struct {
// Request headers
Headers map[string]string
// Request options
Options []i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestOption
// Request query parameters
QueryParameters *AttachmentsRequestBuilderGetQueryParameters
// Response handler to use in place of the default response handling provided by the core service
ResponseHandler i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.ResponseHandler
}
AttachmentsRequestBuilderGetOptions options for Get
type AttachmentsRequestBuilderGetQueryParameters ¶
type AttachmentsRequestBuilderGetQueryParameters struct {
// Include count of items
Count *bool `uriparametername:"%24count"`
// Expand related entities
Expand []string `uriparametername:"%24expand"`
// Filter items by property values
Filter *string `uriparametername:"%24filter"`
// Order items by property values
Orderby []string `uriparametername:"%24orderby"`
// Select properties to be returned
Select []string `uriparametername:"%24select"`
// Skip the first n items
Skip *int32 `uriparametername:"%24skip"`
// Show only the first n items
Top *int32 `uriparametername:"%24top"`
}
AttachmentsRequestBuilderGetQueryParameters the collection of FileAttachment, ItemAttachment, and referenceAttachment attachments for the event. Navigation property. Read-only. Nullable.
type AttachmentsRequestBuilderPostOptions ¶
type AttachmentsRequestBuilderPostOptions struct {
//
Body iadcd81124412c61e647227ecfc4449d8bba17de0380ddda76f641a29edf2b242.Attachmentable
// Request headers
Headers map[string]string
// Request options
Options []i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestOption
// Response handler to use in place of the default response handling provided by the core service
ResponseHandler i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.ResponseHandler
}
AttachmentsRequestBuilderPostOptions options for Post