Documentation
¶
Index ¶
- type PrinterShareItemRequestBuilder
- func (m *PrinterShareItemRequestBuilder) AllowedGroups() ...
- func (m *PrinterShareItemRequestBuilder) AllowedGroupsById(id string) ...
- func (m *PrinterShareItemRequestBuilder) AllowedUsers() ...
- func (m *PrinterShareItemRequestBuilder) AllowedUsersById(id string) ...
- func (m *PrinterShareItemRequestBuilder) CreateDeleteRequestInformation(options *PrinterShareItemRequestBuilderDeleteOptions) (...)
- func (m *PrinterShareItemRequestBuilder) CreateGetRequestInformation(options *PrinterShareItemRequestBuilderGetOptions) (...)
- func (m *PrinterShareItemRequestBuilder) CreatePatchRequestInformation(options *PrinterShareItemRequestBuilderPatchOptions) (...)
- func (m *PrinterShareItemRequestBuilder) Delete(options *PrinterShareItemRequestBuilderDeleteOptions) error
- func (m *PrinterShareItemRequestBuilder) Get(options *PrinterShareItemRequestBuilderGetOptions) (...)
- func (m *PrinterShareItemRequestBuilder) Patch(options *PrinterShareItemRequestBuilderPatchOptions) error
- func (m *PrinterShareItemRequestBuilder) Printer() ...
- type PrinterShareItemRequestBuilderDeleteOptions
- type PrinterShareItemRequestBuilderGetOptions
- type PrinterShareItemRequestBuilderGetQueryParameters
- type PrinterShareItemRequestBuilderPatchOptions
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type PrinterShareItemRequestBuilder ¶
type PrinterShareItemRequestBuilder struct {
// contains filtered or unexported fields
}
PrinterShareItemRequestBuilder provides operations to manage the shares property of the microsoft.graph.print entity.
func NewPrinterShareItemRequestBuilder ¶
func NewPrinterShareItemRequestBuilder(rawUrl string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *PrinterShareItemRequestBuilder
NewPrinterShareItemRequestBuilder instantiates a new PrinterShareItemRequestBuilder and sets the default values.
func NewPrinterShareItemRequestBuilderInternal ¶
func NewPrinterShareItemRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *PrinterShareItemRequestBuilder
NewPrinterShareItemRequestBuilderInternal instantiates a new PrinterShareItemRequestBuilder and sets the default values.
func (*PrinterShareItemRequestBuilder) AllowedGroups ¶
func (m *PrinterShareItemRequestBuilder) AllowedGroups() *if71bc0def059e5cd43ad758ac90e0476d545be67abc269b44c62b0e319bd0c1c.AllowedGroupsRequestBuilder
AllowedGroups the allowedGroups property
func (*PrinterShareItemRequestBuilder) AllowedGroupsById ¶
func (m *PrinterShareItemRequestBuilder) AllowedGroupsById(id string) *i19852dfc496eca0fe63108cfac8774cb2809469b264ed6de9f0834e636ab428c.GroupItemRequestBuilder
AllowedGroupsById gets an item from the github.com/microsoftgraph/msgraph-sdk-go/.print.shares.item.allowedGroups.item collection
func (*PrinterShareItemRequestBuilder) AllowedUsers ¶
func (m *PrinterShareItemRequestBuilder) AllowedUsers() *i35c871e364b7bd9c669482c3e558d704d96c2c6922e224cf70fc6ba4cb816548.AllowedUsersRequestBuilder
AllowedUsers the allowedUsers property
func (*PrinterShareItemRequestBuilder) AllowedUsersById ¶
func (m *PrinterShareItemRequestBuilder) AllowedUsersById(id string) *i30908241df49cb55a70218cf04d4d0e1e3dfdde514367f11bb0ada2960507068.UserItemRequestBuilder
AllowedUsersById gets an item from the github.com/microsoftgraph/msgraph-sdk-go/.print.shares.item.allowedUsers.item collection
func (*PrinterShareItemRequestBuilder) CreateDeleteRequestInformation ¶
func (m *PrinterShareItemRequestBuilder) CreateDeleteRequestInformation(options *PrinterShareItemRequestBuilderDeleteOptions) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
CreateDeleteRequestInformation delete navigation property shares for print
func (*PrinterShareItemRequestBuilder) CreateGetRequestInformation ¶
func (m *PrinterShareItemRequestBuilder) CreateGetRequestInformation(options *PrinterShareItemRequestBuilderGetOptions) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
CreateGetRequestInformation the list of printer shares registered in the tenant.
func (*PrinterShareItemRequestBuilder) CreatePatchRequestInformation ¶
func (m *PrinterShareItemRequestBuilder) CreatePatchRequestInformation(options *PrinterShareItemRequestBuilderPatchOptions) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
CreatePatchRequestInformation update the navigation property shares in print
func (*PrinterShareItemRequestBuilder) Delete ¶
func (m *PrinterShareItemRequestBuilder) Delete(options *PrinterShareItemRequestBuilderDeleteOptions) error
Delete delete navigation property shares for print
func (*PrinterShareItemRequestBuilder) Get ¶
func (m *PrinterShareItemRequestBuilder) Get(options *PrinterShareItemRequestBuilderGetOptions) (iadcd81124412c61e647227ecfc4449d8bba17de0380ddda76f641a29edf2b242.PrinterShareable, error)
Get the list of printer shares registered in the tenant.
func (*PrinterShareItemRequestBuilder) Patch ¶
func (m *PrinterShareItemRequestBuilder) Patch(options *PrinterShareItemRequestBuilderPatchOptions) error
Patch update the navigation property shares in print
func (*PrinterShareItemRequestBuilder) Printer ¶
func (m *PrinterShareItemRequestBuilder) Printer() *i48812370840add29fbda20a153052c7c465785cc5280697e04043880e76211ef.PrinterRequestBuilder
Printer the printer property
type PrinterShareItemRequestBuilderDeleteOptions ¶
type PrinterShareItemRequestBuilderDeleteOptions struct {
Headers map[string]string
Options []i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestOption
ResponseHandler i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.ResponseHandler
}
PrinterShareItemRequestBuilderDeleteOptions options for Delete
type PrinterShareItemRequestBuilderGetOptions ¶
type PrinterShareItemRequestBuilderGetOptions struct {
Headers map[string]string
Options []i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestOption
QueryParameters *PrinterShareItemRequestBuilderGetQueryParameters
ResponseHandler i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.ResponseHandler
}
PrinterShareItemRequestBuilderGetOptions options for Get
type PrinterShareItemRequestBuilderGetQueryParameters ¶
type PrinterShareItemRequestBuilderGetQueryParameters struct {
Expand []string `uriparametername:"%24expand"`
Select []string `uriparametername:"%24select"`
}
PrinterShareItemRequestBuilderGetQueryParameters the list of printer shares registered in the tenant.
type PrinterShareItemRequestBuilderPatchOptions ¶
type PrinterShareItemRequestBuilderPatchOptions struct {
Body iadcd81124412c61e647227ecfc4449d8bba17de0380ddda76f641a29edf2b242.PrinterShareable
Headers map[string]string
Options []i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestOption
ResponseHandler i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.ResponseHandler
}
PrinterShareItemRequestBuilderPatchOptions options for Patch